@@ -1,6 +1,6 @@
 package TOML::Tiny;
 # ABSTRACT: a minimal, pure perl TOML parser and serializer
-$TOML::Tiny::VERSION = '0.10';
+$TOML::Tiny::VERSION = '0.11';
 use strict;
 use warnings;
 no warnings qw(experimental);
@@ -76,7 +76,7 @@ TOML::Tiny - a minimal, pure perl TOML parser and serializer
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -103,10 +103,16 @@ version 0.10
 
 =head1 DESCRIPTION
 
+=for html <p>
+  <a href="https://github.com/sysread/TOML-Tiny/actions?query=workflow%3Arun-tests">
+    <img src="https://github.com/sysread/TOML-Tiny/workflows/run-tests/badge.svg" alt="Build status" />
+  </a>
+</p>
+
 C<TOML::Tiny> implements a pure-perl parser and generator for the
-L<TOML|https://github.com/toml-lang/toml> data format. It conforms to TOML v5
+L<TOML|https://github.com/toml-lang/toml> data format. It conforms to TOML v0.5
 (with a few caveats; see L</strict_arrays>) with support for more recent
-changes in pursuit of v6.
+changes in pursuit of v1.0.
 
 C<TOML::Tiny> strives to maintain an interface compatible to the L<TOML> and
 L<TOML::Parser> modules, and could even be used to override C<$TOML::Parser>:
@@ -326,8 +332,8 @@ routine.
 
 =item strict_arrays
 
-C<TOML v5> specified homogenous arrays. This has since been removed and will no
-longer be part of the standard as of C<v6> (as of the time of writing; the
+C<TOML v0.5> specified homogenous arrays. This has since been removed and will no
+longer be part of the standard as of C<v1.0> (as of the time of writing; the
 author of C<TOML> has gone back and forth on the issue, so no guarantees).
 
 By default, C<TOML::Tiny> is flexible and supports heterogenous arrays. If you
@@ -358,8 +364,8 @@ particularly in adding support for newer C<TOML> features and strictness.
 
 L<TOML> defaults to lax parsing and provides C<strict_mode> to (slightly)
 tighten things up. C<TOML::Tiny> defaults to (somehwat) stricter parsing, with
-the exception of permitting heterogenous arrays (illegal in v4 and v5, but
-permissible in the upcoming v6); optional enforcement of homogenous arrays is
+the exception of permitting heterogenous arrays (illegal in v4 and v0.5, but
+permissible in the upcoming v1.0); optional enforcement of homogenous arrays is
 supported with C<strict_arrays>.
 
 C<TOML::Tiny> supports a number of options which do not exist in L<TOML>:
@@ -423,7 +429,7 @@ Jeff Ober <sysread@fastmail.fm>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Jeff Ober.
+This software is copyright (c) 2021 by Jeff Ober.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
